@@ -2,12 +2,12 @@ from __future__ import unicode_literals, division, absolute_import
 from collections import Mapping
 import logging
 import subprocess
-import sys
 
 
 from flexget import plugin
 from flexget.event import event
 from flexget.utils.template import render_from_entry, render_from_task, RenderError
+from flexget.utils.tools import io_encoding
 
 log = logging.getLogger('exec')
 
@@ -95,16 +95,16 @@ class PluginExec(object):
         if isinstance(config, basestring):
             config = {'on_output': {'for_accepted': config}}
         if not config.get('encoding'):
-            config['encoding'] = sys.getfilesystemencoding()
+            config['encoding'] = io_encoding
         return config
 
     def execute_cmd(self, cmd, allow_background, encoding):
         log.verbose('Executing: %s' % cmd)
         p = subprocess.Popen(cmd.encode(encoding), shell=True, stdin=subprocess.PIPE, stdout=subprocess.PIPE,
-            stderr=subprocess.STDOUT, close_fds=False)
+                             stderr=subprocess.STDOUT, close_fds=False)
         if not allow_background:
             (r, w) = (p.stdout, p.stdin)
-            response = r.read()
+            response = r.read().decode(encoding, 'replace')
             r.close()
             w.close()
             if response:
